@@ -5,7 +5,7 @@ use warnings;
 
 package WWW::Shopify::Field::Identifier;
 use parent 'WWW::Shopify::Field';
-sub sql_type { return "int"; }
+sub sql_type { return "bigint"; }
 
 sub generate($) {
 	return int(rand(100000000))+1;
